Module backup

Module backup 

Functions

backup_prefix
Generate a backup prefix that uniquely identifies a source file by its canonical path.
create_backup
Create a timestamped backup of source in backup_dir.
list_backups
List backups for source in backup_dir, sorted newest-first.
list_undone
List undone (consumed) backups for source in backup_dir, sorted newest-first.
prune_backups
Remove old backups for source that exceed history_size.
write_with_backup
Atomically write a Document to path, creating a backup first.