Module filter

Module filter 

Structs

FilterOptions
Aggregated filter parameters for the entry filter pipeline.

Enums

Age
Which end of the chronological list to keep when applying a count limit.

Functions

filter_entries
Filter a collection of entries through the filter pipeline.