Structs
- Filter
Options - Aggregated filter parameters for the entry filter pipeline.
Enums
- Age
- Which end of the chronological list to keep when applying a count limit.
Functions
- filter_
entries - Filter a collection of entries through the filter pipeline.